<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl_PL">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Wybierz jedno lub wiele urządzeń</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Tryb okna</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Tryb pełnoekranowy</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Konfiguracja powiodła się</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Zamknij okno i ponownie uruchom vokoscreenNG.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Baw się dobrze z vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Wybierz jedno lub wiele urządzeń</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Brak menedżera plików.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Zainstaluj menedżer plików.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Uwaga</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Za mało miejsca na dysku, nagrywanie nie zostało rozpoczęte.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Osiągnięgo limit miejsca na dysku.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limit miejsca na dysku</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Nagrywanie zatrzymane, za mało miejsca na dysku.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>Brak menedżera plików.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Zainstaluj menedżer plików.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Kod źródłowy</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Strona domowa</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Tłumaczenia</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Darowizna</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Wybierz jedno lub wiele urządzeń</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Obszar</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Obszar</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Brak menedżera plików.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Zainstaluj menedżer plików.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Kontynuuj</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Powiększenie</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Kontynuuj</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Powiększenie</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Przerzuć horyzontalnie</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Przerzuć pionowo</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Odwróć</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Szary</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Czarno-białe</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Usuń ramkę okna</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Ustawienia kamery</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Obszar</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Resetuj</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Powiększenie</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odliczanie</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Rozmiar wideo:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Wolne miejsce na dysku:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacje</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Czas nagrania:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Klatki</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Kodek wideo</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Kodek audio</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Jakość</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nie nagrywaj kursora myszy</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Godzina</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuta</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Włącz odliczanie</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Zakończ nagrywanie po</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Godzin</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minut</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekund</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Zapisz nagranie w</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limit miejsca na dysku</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Pokazuj w panelu systemowym</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Sekund do nagrania</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Sprawdź aktualizacje</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Wideo</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Dostępne</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Niedostępne</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Kontynuuj</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Odtwórz</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Folder</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Odwróć</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Szary</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Odtwórz ostatnie nagranie</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otwórz folder</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Zminimalizuj po rozpoczęniu nagrania</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Startuje zminimalizowany</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Odwróć poziomo</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Odwróć pionowo</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Czarno-białe</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Usuń ramkę okna</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Darowizna</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Zresetuj ustawienia przy następnym uruchomieniu</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Prawa autorskie i licencja z obrazu</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Przesyłanie ekranu</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Odtwarzacz</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Wykonaj rzut obrazu kart</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Informacja o licencji</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>WŁ.</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>WYŁ.</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Globalne skróty klawiaturowe</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Przypisane klawisze skrótów.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Skrót klawiaturowy nie został przypisany lub przypisany więcej niż jeden raz</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Jeśli został przypisany, ale nie działa, jest używany przez inny program.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Migawka</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Ścieżka obrazu</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Ukryj to okno</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Sekundy oczekiwania przed rozpoczęciem nagrania</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Prawa autorskie i licencja z obrazu</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Odtwórz</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Otwórz plik</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Poprzednia klatka</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Następna klatka</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Wycisz</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Przesuń menu</translation>
    </message>
</context>
</TS>